pub fn detect(path: &Path) -> Option<&'static LanguageSupport>Expand description
The language owning path, or None if drep does not analyze it.
Case-insensitive, matching the rest of drep’s file-target policy.
pub fn detect(path: &Path) -> Option<&'static LanguageSupport>The language owning path, or None if drep does not analyze it.
Case-insensitive, matching the rest of drep’s file-target policy.